diff -urNp gmp-4.3.1/gmp-impl.h gmp/gmp-impl.h
--- gmp-4.3.1/gmp-impl.h	2009-05-12 09:12:12.000000000 +0300
+++ gmp/gmp-impl.h	2009-09-12 14:06:03.000000000 +0300
@@ -198,6 +198,20 @@ typedef unsigned long       gmp_uint_lea
 #endif
 
 
+/* gmp_intptr_t, for pointer to integer casts */
+#if HAVE_INTPTR_T
+typedef intptr_t            gmp_intptr_t;
+#elif (SIZOF_VOIDP == SIZEOF_PTRDIFF_T)
+typedef ptrdiff_t           gmp_intptr_t;
+#elif (SIZOF_VOIDP == SIZEOF_LONG)
+typedef long                gmp_intptr_t;
+#elif (SIZOF_VOIDP == SIZEOF_LONG_LONG)
+typedef long long           gmp_intptr_t;
+#else /* fallback */
+typedef size_t              gmp_intptr_t;
+#endif
+
+
 /* const and signed must match __gmp_const and __gmp_signed, so follow the
    decision made for those in gmp.h.    */
 #if ! __GMP_HAVE_CONST
diff -urNp gmp-4.3.1/configure.in gmp/configure.in
--- gmp-4.3.1/configure.in	2009-05-12 09:12:12.000000000 +0300
+++ gmp/configure.in	2009-09-12 14:11:06.000000000 +0300
@@ -3099,6 +3099,12 @@ fi
 # of any sensible system.  In a generic C build, grepping LONG_BIT out of
 # <limits.h> might be an alternative, for maximum portability.
 #
+AC_CHECK_TYPES(intptr_t)
+AC_CHECK_SIZEOF(void*)
+AC_CHECK_SIZEOF(ptrdiff_t)
+AC_CHECK_SIZEOF(size_t)
+AC_CHECK_SIZEOF(long)
+AC_CHECK_SIZEOF(long long)
 AC_CHECK_SIZEOF(unsigned short)
 AC_CHECK_SIZEOF(unsigned)
 AC_CHECK_SIZEOF(unsigned long)
diff -urNp gmp-4.3.1/config.in gmp/config.in
--- gmp-4.3.1/config.in	2009-05-12 09:12:46.000000000 +0300
+++ gmp/config.in	2009-09-12 14:11:33.000000000 +0300
@@ -161,6 +161,9 @@ along with the GNU MP Library.  If not, 
 /* Define to 1 if the system has the type `intmax_t'. */
 #undef HAVE_INTMAX_T
 
+/* Define to 1 if the system has the type `intptr_t'. */
+#undef HAVE_INTPTR_T
+
 /* Define to 1 if you have the <inttypes.h> header file. */
 #undef HAVE_INTTYPES_H
 
@@ -447,9 +450,21 @@ along with the GNU MP Library.  If not, 
 /* Define as the return type of signal handlers (`int' or `void'). */
 #undef RETSIGTYPE
 
+/* The size of a `long', as computed by sizeof. */
+#undef SIZEOF_LONG
+
+/* The size of a `long long', as computed by sizeof. */
+#undef SIZEOF_LONG_LONG
+
 /* The size of a `mp_limb_t', as computed by sizeof. */
 #undef SIZEOF_MP_LIMB_T
 
+/* The size of a `ptrdiff_t', as computed by sizeof. */
+#undef SIZEOF_PTRDIFF_T
+
+/* The size of a `size_t', as computed by sizeof. */
+#undef SIZEOF_SIZE_T
+
 /* The size of a `unsigned', as computed by sizeof. */
 #undef SIZEOF_UNSIGNED
 
@@ -459,6 +474,9 @@ along with the GNU MP Library.  If not, 
 /* The size of a `unsigned short', as computed by sizeof. */
 #undef SIZEOF_UNSIGNED_SHORT
 
+/* The size of a `void*', as computed by sizeof. */
+#undef SIZEOF_VOIDP
+
 /* Define to 1 if sscanf requires writable inputs */
 #undef SSCANF_WRITABLE_INPUT
 
